.. _api:

Developer Interface
===================

.. module:: dyndnsc

This part of the documentation should cover all the relevant interfaces of `dyndnsc`.

Main Interface
--------------

All of dyndnsc' functionality can be accessed by these methods.


.. autoclass:: dyndnsc.DynDnsClient
   :inherited-members:
